@@ -1,6 +1,6 @@
 from myprss.config import Config
 
 
-def list_known_feeds(ctx):
+def list_known_feeds(ctx, args, incomplete):
     config = Config()
     return list(config["registry"].keys())
